@@ -1,4 +1,5 @@
 package XML::Comma::Configuration;
+
 use base 'XML::Comma::Pkg::ModuleConfiguration'; 1;
 __DATA__
 
@@ -27,7 +28,7 @@ defs_extension    =>     '.def',
 macro_extension   =>     '.macro',
 include_extension =>     '.include',
 
-#do we validate a doc created with new( [ file | block ] => ... )?
+#should we auto-validate a doc created with new( [ file | block ] => ... )?
 validate_new      =>     1,
 
 parser            =>     'PurePerl',
@@ -41,18 +42,43 @@ mysql =>
         PrintError => 0,
         ShowErrorStatement => 1,
         AutoCommit => 1,
-      } ],
+      }
+    ],
   },
 postgres =>
   { sql_syntax  =>  'Pg',
     dbi_connect_info => 
-    [ 'DBI:Pg:dbname=comma', '', '',
+    [ 'DBI:Pg:dbname=comma', 'comma', 'test',
       { RaiseError => 1,
         PrintError => 0,
         ShowErrorStatement => 1,
         AutoCommit => 1,
-      } ],
+      }
+    ],
   },
+sqlite =>
+  { sql_syntax  =>  'SQLite',
+    dbi_connect_info =>
+    [ 'DBI:SQLite:test.db', '', '',
+      { RaiseError => 1, 	 
+        PrintError => 1, 	 
+        ShowErrorStatement => 1, 	 
+        AutoCommit => 1, 	 
+        HandleError => sub { 	 
+          my ( $string, $handle ) = @_; 	 
+          # print "handling error ($handle)\n"; 	 
+          if ( $string =~ m|schema has changed| ) { 	 
+            $handle->execute(); 	 
+            return 1; 	 
+          } 	 
+          return; 	 
+        }, 	 
+      }
+    ], 	 
+  },
+### please note that postgres support is beta, and sqlite support is 
+### broken. mysql is recommended for production environments.
 system_db        => 'mysql',
 #system_db        => 'postgres',
+##system_db        => 'sqlite-DANGER-READ-NOTE-ABOVE',
 
