@@ -1200,14 +1200,15 @@ sub sql_clear_all_comma_flags {
 }
 
 sub sql_clean_find_orphans {
-  my ( $self, $table_name, $data_table_name ) = @_;
-  return qq[ 
-             SELECT $table_name.doc_id 
-               FROM $table_name 
-               WHERE $table_name.doc_id NOT IN ( 
-                 SELECT $data_table_name.doc_id 
-                   FROM $data_table_name
-               )
+  my ( $index, $table_name, $data_table_name ) = @_;
+
+  return 
+  qq[
+      SELECT $table_name.doc_id 
+      FROM $table_name 
+      LEFT JOIN $data_table_name 
+        ON $table_name.doc_id = $data_table_name.doc_id 
+	      WHERE $data_table_name.doc_id is NULL
   ];
 }
 
@@ -1356,6 +1357,11 @@ sub sql_select_from_data {
        $do_count_only,
        $aggregate_function ) = @_;
 
+XML::Comma::Log->warn("column_list: ".join(",",@$columns_list));
+XML::Comma::Log->warn("from_tables: ".join(",",@$from_tables));
+XML::Comma::Log->warn("where_clause: $where_clause");
+XML::Comma::Log->warn("collection_spec: $collection_spec");
+
   #dbg 'select_from_data', $where_clause;
   my $data_table_name = $index->data_table_name();
   # more hard-coded crappyness.  If we aliased the tables for a 
@@ -1417,12 +1423,27 @@ sub sql_select_from_data {
   # from tables
   my $from = ' FROM ' . join ( ',', @{$from_tables} );
 
+  if(@$from_tables > 1 && grep /\s+AS\s+/, @$from_tables) {
+    #prepend t01. on every term in $where_clause
+    #TODO: think about using SQL::Statement or whatev as well for supa safety
+    my %has_col = map { lc($_) => 1 }
+      (@$columns_list, 'doc_id', 'record_last_modified');
+XML::Comma::Log->warn("about to munge: $where_clause");
+    #TODO: think, what other seperators can we have?
+    $where_clause = join("", map {
+        $has_col{lc($_)} ? "t01.$_" : $_
+      } split(/(\s+|<=|>=|>|=|<)/, $where_clause));
+XML::Comma::Log->warn("pooped out:     $where_clause");
+  }
+
   # where clause
   my $where = ' WHERE 1=1';
   $where .= " AND ($where_clause)"     if  $where_clause;
   $where .= " AND $collection_spec"  if  $collection_spec;
   $where .= " AND ($textsearch_spec)"  if  $textsearch_spec;
 
+XML::Comma::Log->warn("where: $where");
+
   # having clause
   my $having = '';
   $having .= " HAVING ($having_clause)" if $having_clause;
@@ -1525,5 +1546,6 @@ sub sql_drop_any_temp_tables {
 }
 
 
+
 1;
 
